# -*- coding: utf-8 -*-

import urllib

import requests
from django.urls import reverse


class RemoteTestMixin:
    # PROFILE
    def v1_role_profile_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_profile_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_profile_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_profile_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_profile_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_profile_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_profile_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_profile_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_profile_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ROLE
    def v1_role_role_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_role_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_role_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_role_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_role_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_role_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_role_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_role_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_role_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # MENU
    def v1_role_menu_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_menu_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_menu_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_menu_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_menu_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_menu_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_menu_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_menu_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_menu_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # MENU TRANSLATION
    def v1_role_menu_translation_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menutranslation-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_menu_translation_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menutranslation-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_menu_translation_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menutranslation-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_menu_translation_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menutranslation-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_menu_translation_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menutranslation-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_menu_translation_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menutranslation-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_menu_translation_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menutranslation-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_menu_translation_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menutranslation-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_menu_translation_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menutranslation-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
