# -*- coding: utf-8 -*-
from django.conf import settings
from thx.core.management.commands import ThxBaseCommand

from thx.role.utils import InitialRole


class Command(ThxBaseCommand):
    help = "Populate Role data"

    def create_parser(self, prog_name, subcommand, **kwargs):
        parser = super().create_parser(prog_name, subcommand, **kwargs)
        parser.add_argument(
            '-u', '--user-id', type=int, default=1, help='User that apply operation.',
        )
        parser.add_argument(
            '-p', '--profiles',
            nargs='+', type=str, default=settings.THX_ROLE_PROFILES, help='Profiles to be generated',
        )
        # TODO: parametro --clean: ripulisce i role non più necessari: deve chiedere doppia conferma!!
        return parser

    def handle(self, *args, **options):
        try:
            initializer = InitialRole(user_id=options['user_id'], profiles=options['profiles'])
            profiles, roles = initializer.insert_all()
            self.logger.info("Execution finished")
            self.logger.info("Imported profiles: %s", [profile[0].name for profile in profiles if profile[1]])
            self.logger.info("Imported roles: %s", [str(role[0]) for role in roles if role[1]])
        except Exception as e:
            self.stdout.write(self.style.ERROR(f'Execution failed: {e}'))
            self.logger.exception(e)
