# Generated by Django 3.2.19 on 2023-07-17 10:38

from django.db import migrations


def get_user_id(apps):
    User = apps.get_model("account", "User")
    try:
        return User.objects.filter(is_superuser=True).first().id
    except AttributeError:
        try:
            return User.objects.filter(is_staff=True).first().id
        except AttributeError:
            try:
                return User.objects.first().id
            except AttributeError:
                # No data to be migrated
                pass


def migrate_role_actions(apps, schema_editor):
    Profile = apps.get_model("role", "Profile")
    Role = apps.get_model("role", "Role")
    Filter = apps.get_model("role", "Filter")

    user_id = get_user_id(apps)

    Role.objects.bulk_create(
        Role(
            app_label=role.app_label,
            model_name=role.model_name,
            profile=role.profile,
            action=action,
            creator_id=user_id,
            last_modifier_id=user_id
        )
        for role in Role.objects.order_by("app_label", "model_name").distinct("app_label", "model_name")
        for action in (
            Filter
            .objects
            .filter(role=role)
            .values_list("action", flat=True)
            .order_by("action")
            .distinct("action")
        )
    )
    for profile in Profile.objects.all():
        for role in profile.old_roles.all():
            profile.roles.add(*Role.objects.filter(app_label=role.app_label, model_name=role.model_name, action__isnull=False))

    Role.objects.filter(action__isnull=True).delete()


class Migration(migrations.Migration):

    dependencies = [
        ('role', '0010_auto_20230717_1038'),
    ]

    operations = [
        migrations.RunPython(code=migrate_role_actions),
    ]
